# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _capng
else:
    import _capng

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


CAP_CHOWN = _capng.CAP_CHOWN
CAP_DAC_OVERRIDE = _capng.CAP_DAC_OVERRIDE
CAP_DAC_READ_SEARCH = _capng.CAP_DAC_READ_SEARCH
CAP_FOWNER = _capng.CAP_FOWNER
CAP_FSETID = _capng.CAP_FSETID
CAP_KILL = _capng.CAP_KILL
CAP_SETGID = _capng.CAP_SETGID
CAP_SETUID = _capng.CAP_SETUID
CAP_SETPCAP = _capng.CAP_SETPCAP
CAP_LINUX_IMMUTABLE = _capng.CAP_LINUX_IMMUTABLE
CAP_NET_BIND_SERVICE = _capng.CAP_NET_BIND_SERVICE
CAP_NET_BROADCAST = _capng.CAP_NET_BROADCAST
CAP_NET_ADMIN = _capng.CAP_NET_ADMIN
CAP_NET_RAW = _capng.CAP_NET_RAW
CAP_IPC_LOCK = _capng.CAP_IPC_LOCK
CAP_IPC_OWNER = _capng.CAP_IPC_OWNER
CAP_SYS_MODULE = _capng.CAP_SYS_MODULE
CAP_SYS_RAWIO = _capng.CAP_SYS_RAWIO
CAP_SYS_CHROOT = _capng.CAP_SYS_CHROOT
CAP_SYS_PTRACE = _capng.CAP_SYS_PTRACE
CAP_SYS_PACCT = _capng.CAP_SYS_PACCT
CAP_SYS_ADMIN = _capng.CAP_SYS_ADMIN
CAP_SYS_BOOT = _capng.CAP_SYS_BOOT
CAP_SYS_NICE = _capng.CAP_SYS_NICE
CAP_SYS_RESOURCE = _capng.CAP_SYS_RESOURCE
CAP_SYS_TIME = _capng.CAP_SYS_TIME
CAP_SYS_TTY_CONFIG = _capng.CAP_SYS_TTY_CONFIG
CAP_MKNOD = _capng.CAP_MKNOD
CAP_LEASE = _capng.CAP_LEASE
CAP_AUDIT_WRITE = _capng.CAP_AUDIT_WRITE
CAP_AUDIT_CONTROL = _capng.CAP_AUDIT_CONTROL
CAP_SETFCAP = _capng.CAP_SETFCAP
CAP_MAC_OVERRIDE = _capng.CAP_MAC_OVERRIDE
CAP_MAC_ADMIN = _capng.CAP_MAC_ADMIN
CAP_SYSLOG = _capng.CAP_SYSLOG
CAP_WAKE_ALARM = _capng.CAP_WAKE_ALARM
CAP_BLOCK_SUSPEND = _capng.CAP_BLOCK_SUSPEND
CAP_AUDIT_READ = _capng.CAP_AUDIT_READ
CAP_PERFMON = _capng.CAP_PERFMON
CAP_BPF = _capng.CAP_BPF
CAP_CHECKPOINT_RESTORE = _capng.CAP_CHECKPOINT_RESTORE
CAP_LAST_CAP = _capng.CAP_LAST_CAP
CAPNG_DROP = _capng.CAPNG_DROP
CAPNG_ADD = _capng.CAPNG_ADD
CAPNG_EFFECTIVE = _capng.CAPNG_EFFECTIVE
CAPNG_PERMITTED = _capng.CAPNG_PERMITTED
CAPNG_INHERITABLE = _capng.CAPNG_INHERITABLE
CAPNG_BOUNDING_SET = _capng.CAPNG_BOUNDING_SET
CAPNG_AMBIENT = _capng.CAPNG_AMBIENT
CAPNG_SELECT_CAPS = _capng.CAPNG_SELECT_CAPS
CAPNG_SELECT_BOUNDS = _capng.CAPNG_SELECT_BOUNDS
CAPNG_SELECT_BOTH = _capng.CAPNG_SELECT_BOTH
CAPNG_SELECT_AMBIENT = _capng.CAPNG_SELECT_AMBIENT
CAPNG_SELECT_ALL = _capng.CAPNG_SELECT_ALL
CAPNG_FAIL = _capng.CAPNG_FAIL
CAPNG_NONE = _capng.CAPNG_NONE
CAPNG_PARTIAL = _capng.CAPNG_PARTIAL
CAPNG_FULL = _capng.CAPNG_FULL
CAPNG_PRINT_STDOUT = _capng.CAPNG_PRINT_STDOUT
CAPNG_PRINT_BUFFER = _capng.CAPNG_PRINT_BUFFER
CAPNG_NO_FLAG = _capng.CAPNG_NO_FLAG
CAPNG_DROP_SUPP_GRP = _capng.CAPNG_DROP_SUPP_GRP
CAPNG_CLEAR_BOUNDING = _capng.CAPNG_CLEAR_BOUNDING
CAPNG_INIT_SUPP_GRP = _capng.CAPNG_INIT_SUPP_GRP
CAPNG_CLEAR_AMBIENT = _capng.CAPNG_CLEAR_AMBIENT
CAPNG_UNSET_ROOTID = _capng.CAPNG_UNSET_ROOTID
CAPNG_SUPPORTS_AMBIENT = _capng.CAPNG_SUPPORTS_AMBIENT

def capng_clear(set):
    return _capng.capng_clear(set)

def capng_fill(set):
    return _capng.capng_fill(set)

def capng_setpid(pid):
    return _capng.capng_setpid(pid)

def capng_get_caps_process():
    return _capng.capng_get_caps_process()

def capng_update(action, type, capability):
    return _capng.capng_update(action, type, capability)

def capng_updatev(action, type, capability, capability1=-1, capability2=-1, capability3=-1, capability4=-1, capability5=-1, capability6=-1, capability7=-1, capability8=-1, capability9=-1, capability10=-1, capability11=-1, capability12=-1, capability13=-1, capability14=-1, capability15=-1, capability16=-1, capability17=-1, capability18=-1, capability19=-1, capability20=-1, capability21=-1, capability22=-1, capability23=-1, capability24=-1, capability25=-1, capability26=-1, capability27=-1, capability28=-1, capability29=-1, capability30=-1, capability31=-1, capability32=-1, capability33=-1, capability34=-1, capability35=-1, capability36=-1, capability37=-1, capability38=-1, capability39=-1, capability40=-1, capability41=-1, capability42=-1, capability43=-1, capability44=-1, capability45=-1, capability46=-1, capability47=-1, capability48=-1, capability49=-1, capability50=-1, capability51=-1, capability52=-1, capability53=-1, capability54=-1, capability55=-1, capability56=-1, capability57=-1, capability58=-1, capability59=-1, capability60=-1, capability61=-1, capability62=-1, capability63=-1, capability64=-1):
    return _capng.capng_updatev(action, type, capability, capability1, capability2, capability3, capability4, capability5, capability6, capability7, capability8, capability9, capability10, capability11, capability12, capability13, capability14, capability15, capability16, capability17, capability18, capability19, capability20, capability21, capability22, capability23, capability24, capability25, capability26, capability27, capability28, capability29, capability30, capability31, capability32, capability33, capability34, capability35, capability36, capability37, capability38, capability39, capability40, capability41, capability42, capability43, capability44, capability45, capability46, capability47, capability48, capability49, capability50, capability51, capability52, capability53, capability54, capability55, capability56, capability57, capability58, capability59, capability60, capability61, capability62, capability63, capability64)

def capng_apply(set):
    return _capng.capng_apply(set)

def capng_lock():
    return _capng.capng_lock()

def capng_change_id(uid, gid, flag):
    return _capng.capng_change_id(uid, gid, flag)

def capng_get_rootid():
    return _capng.capng_get_rootid()

def capng_set_rootid(rootid):
    return _capng.capng_set_rootid(rootid)

def capng_get_caps_fd(fd):
    return _capng.capng_get_caps_fd(fd)

def capng_apply_caps_fd(fd):
    return _capng.capng_apply_caps_fd(fd)

def capng_have_capabilities(set):
    return _capng.capng_have_capabilities(set)

def capng_have_permitted_capabilities():
    return _capng.capng_have_permitted_capabilities()

def capng_have_capability(which, capability):
    return _capng.capng_have_capability(which, capability)

def capng_print_caps_numeric(where, set):
    return _capng.capng_print_caps_numeric(where, set)

def capng_print_caps_text(where, which):
    return _capng.capng_print_caps_text(where, which)

def capng_name_to_capability(name):
    return _capng.capng_name_to_capability(name)

def capng_capability_to_name(capability):
    return _capng.capng_capability_to_name(capability)

